<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="31"/>
        <source>Re&amp;gion:</source>
        <translation>&amp;Alue:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="60"/>
        <source>De&amp;tailed Settings</source>
        <translation>&amp;Tarkat asetukset</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="78"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Numerot:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="107"/>
        <source>&amp;Time:</source>
        <translation>A&amp;ika:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="136"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Valuutta:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="165"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Mittayksiköt:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="194"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>Aa&amp;kkostus ja lajittelu:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="226"/>
        <source>Examples</source>
        <translation>Esimerkit</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>Numbers:</source>
        <translation>Numerot:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="258"/>
        <source>Time:</source>
        <translation>Aika:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="289"/>
        <source>Currency:</source>
        <translation>Valuutta:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="309"/>
        <source>Measurement Units:</source>
        <translation>Mittayksiköt:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="164"/>
        <source>Unset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="226"/>
        <source>Current: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="370"/>
        <source>Format Settings Changed</source>
        <translation>Muotoasetukset muutettu</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="371"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Haluatko tallentaa muutokset? Muutokset tulevat voimaan, kun kirjaudut uudelleen sisään.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="518"/>
        <source>Imperial UK</source>
        <translation>Brittiläinen</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="522"/>
        <source>Imperial US</source>
        <translation>Amerikkalainen</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="526"/>
        <source>Metric</source>
        <translation>Metrinen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>LXQt Locale Configuration</source>
        <translation>LXQt:n maa-asetukset</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Locale Settings</source>
        <translation>Maa-asetukset</translation>
    </message>
</context>
</TS>
